@@ -8,7 +8,7 @@ summary: >
 # Proximal Policy Optimization - PPO
 
 This is a [PyTorch](https://pytorch.org) implementation of
-[Proximal Policy Optimization - PPO](https://arxiv.org/abs/1707.06347).
+[Proximal Policy Optimization - PPO](https://papers.labml.ai/paper/1707.06347).
 
 PPO is a policy gradient method for reinforcement learning.
 Simple policy gradient methods do a single gradient update per sample (or a set of samples).
@@ -112,7 +112,7 @@ class ClippedPPOLoss(Module):
     The error we introduce to $J(\pi_\theta) - J(\pi_{\theta_{OLD}})$
      by this assumption is bound by the KL divergence between
      $\pi_\theta$ and $\pi_{\theta_{OLD}}$.
-    [Constrained Policy Optimization](https://arxiv.org/abs/1705.10528)
+    [Constrained Policy Optimization](https://papers.labml.ai/paper/1705.10528)
      shows the proof of this. I haven't read it.
 
 
@@ -136,8 +136,8 @@ class ClippedPPOLoss(Module):
     def __init__(self):
         super().__init__()
 
-    def __call__(self, log_pi: torch.Tensor, sampled_log_pi: torch.Tensor,
-                 advantage: torch.Tensor, clip: float) -> torch.Tensor:
+    def forward(self, log_pi: torch.Tensor, sampled_log_pi: torch.Tensor,
+                advantage: torch.Tensor, clip: float) -> torch.Tensor:
         # ratio $r_t(\theta) = \frac{\pi_\theta (a_t|s_t)}{\pi_{\theta_{OLD}} (a_t|s_t)}$;
         # *this is different from rewards* $r_t$.
         ratio = torch.exp(log_pi - sampled_log_pi)
@@ -200,7 +200,8 @@ class ClippedValueFunctionLoss(Module):
      significantly from $V_{\theta_{OLD}}$.
 
     """
-    def __call__(self, value: torch.Tensor, sampled_value: torch.Tensor, sampled_return: torch.Tensor, clip: float):
+
+    def forward(self, value: torch.Tensor, sampled_value: torch.Tensor, sampled_return: torch.Tensor, clip: float):
         clipped_value = sampled_value + (value - sampled_value).clamp(min=-clip, max=clip)
         vf_loss = torch.max((value - sampled_return) ** 2, (clipped_value - sampled_return) ** 2)
         return 0.5 * vf_loss.mean()
